@@ -1,15 +1,15 @@
 SPCAvRP_deflation <- function( data               # either the data matrix or the sample covariance matrix
                              , cov = FALSE        # TRUE if data is given as a sample covariance matrix 
-                             , s                  # the dimension of the eigenspace (the number of principal components)
-                             , l                  # sparsity level of the eigenvectors (array of lenght s) 
-                             , d = 10             # dimension of the random projections (if k is known, use d = k)
-                             , A = 300            # number of projections to aggregate 
-                             , B = 100            # number of projections in a group
+                             , m                  # the number of principal eigenvectors to estimate
+                             , l                  # sparsity levels of the eigenvectors (array of lenght m) 
+                             , d = 20             # dimension of the random projections (if k is known, use d = k)
+                             , A = 600            # number of projections to aggregate 
+                             , B = 200            # number of projections in a group
                              , center_data = TRUE # TRUE if the data matrix should be centered 
 )
   # output : a list of two elements
-  #             output$vector : a matrix of dimension pxs with its columns as estimated eigenvectors of sparsity level l 
-  #             output$value  : an array of dimesnin s with estimated eigenvalues
+  #             output$vector : a matrix of dimension pxm with its columns as estimated eigenvectors  
+  #             output$value  : an array of dimension m with estimated eigenvalues
 {
   if( !cov & center_data ){
     data <- scale(data, center_data, FALSE)
@@ -23,16 +23,16 @@ SPCAvRP_deflation <- function( data               # either the data matrix or th
     print('SPCAvRP: since p > 2*d*sqrt(A*B), computation of p x p sample covariance is avoided')
   }
   
-  lambda_hat <- rep(0,s)
-  v_hat <- matrix(rep(0,s*p), nrow = p)
+  lambda_hat <- rep(0,m)
+  v_hat <- matrix(rep(0,m*p), nrow = p)
   v_hat_supp <- NULL
   spca_1 <- SPCAvRP(data, cov, l[1], d, A, B, center_data = FALSE) # can be any SPCA algorithm
   v_hat[,1] <- spca_1$vector
   lambda_hat[1] <- spca_1$value
-  if(s>1){
+  if(m>1){
     v_hat_supp[[1]] <-  which(v_hat[,1]!=0, arr.ind = T)
     Hdata <- data
-    for(i in 2:s){
+    for(i in 2:m){
       H <- diag(length(v_hat_supp[[i-1]])) - tcrossprod(v_hat[v_hat_supp[[i-1]],i-1])
       if(cov == TRUE){
         Hdata[v_hat_supp[[i-1]],v_hat_supp[[i-1]]] <- H%*%Hdata[v_hat_supp[[i-1]],v_hat_supp[[i-1]]]%*%H
